==> seabreeze-1.1.0.tar.gz: seabreeze-1.1.0/src/libseabreeze/src/vendors/OceanOptics/protocols/obp/exchanges/OBPContinuousStrobePeriodExchange.cpp <==
/***************************************************//**
 * @file    OBPContinuousStrobePeriodExchange.cpp
 * @date    February 2011
 * @author  Ocean Optics, Inc.
 *
 * LICENSE:
 *
 * SeaBreeze Copyright (C) 2014, Ocean Optics Inc
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject
 * to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *******************************************************/

#include "common/globals.h"
#include "vendors/OceanOptics/protocols/obp/exchanges/OBPContinuousStrobePeriodExchange.h"
#include "vendors/OceanOptics/protocols/obp/hints/OBPControlHint.h"
#include "vendors/OceanOptics/protocols/obp/constants/OBPMessageTypes.h"

using namespace seabreeze;
using namespace seabreeze::oceanBinaryProtocol;

static const unsigned long DEFAULT_PERIOD_USEC = 100000;

OBPContinuousStrobePeriodExchange::OBPContinuousStrobePeriodExchange() {

    this->hints->push_back(new OBPControlHint());

    this->messageType = OBPMessageTypes::OBP_SET_CONT_STROBE_PERIOD;

    this->payload.resize(sizeof(unsigned int));

    /* Set a reasonable default */
    unsigned long period = DEFAULT_PERIOD_USEC;
    this->payload[0] = (byte) (period & 0x00FF);
    this->payload[1] = (byte) ((period >> 8) & 0x00FF);
    this->payload[2] = (byte) ((period >> 16) & 0x00FF);
    this->payload[3] = (byte) ((period >> 24) & 0x00FF);
}

OBPContinuousStrobePeriodExchange::~OBPContinuousStrobePeriodExchange() {

}

void OBPContinuousStrobePeriodExchange::setContinuousStrobePeriodMicroseconds(
        unsigned long period_usec) {
    this->payload[0] = (byte) (period_usec & 0x00FF);
    this->payload[1] = (byte) ((period_usec >> 8) & 0x00FF);
    this->payload[2] = (byte) ((period_usec >> 16) & 0x00FF);
    this->payload[3] = (byte) ((period_usec >> 24) & 0x00FF);
}

==> seabreeze-2.0.3.tar.gz: seabreeze-2.0.3/src/libseabreeze/src/vendors/OceanOptics/protocols/obp/exchanges/OBPContinuousStrobePeriodExchange.cpp <==
/***************************************************//**
 * @file    OBPContinuousStrobePeriodExchange.cpp
 * @date    February 2011
 * @author  Ocean Optics, Inc.
 *
 * LICENSE:
 *
 * SeaBreeze Copyright (C) 2014, Ocean Optics Inc
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject
 * to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *******************************************************/

#include "common/globals.h"
#include "vendors/OceanOptics/protocols/obp/exchanges/OBPContinuousStrobePeriodExchange.h"
#include "vendors/OceanOptics/protocols/obp/hints/OBPControlHint.h"
#include "vendors/OceanOptics/protocols/obp/constants/OBPMessageTypes.h"

using namespace seabreeze;
using namespace seabreeze::oceanBinaryProtocol;

static const unsigned long DEFAULT_PERIOD_USEC = 100000;

OBPContinuousStrobePeriodExchange::OBPContinuousStrobePeriodExchange() {

    this->hints->push_back(new OBPControlHint());

    this->messageType = OBPMessageTypes::OBP_SET_CONT_STROBE_PERIOD;

    this->payload.resize(sizeof(unsigned int));

    /* Set a reasonable default */
    unsigned long period = DEFAULT_PERIOD_USEC;
    this->payload[0] = (unsigned char) (period & 0x00FF);
    this->payload[1] = (unsigned char) ((period >> 8) & 0x00FF);
    this->payload[2] = (unsigned char) ((period >> 16) & 0x00FF);
    this->payload[3] = (unsigned char) ((period >> 24) & 0x00FF);
}

OBPContinuousStrobePeriodExchange::~OBPContinuousStrobePeriodExchange() {

}

void OBPContinuousStrobePeriodExchange::setContinuousStrobePeriodMicroseconds(
        unsigned long period_usec) {
    this->payload[0] = (unsigned char) (period_usec & 0x00FF);
    this->payload[1] = (unsigned char) ((period_usec >> 8) & 0x00FF);
    this->payload[2] = (unsigned char) ((period_usec >> 16) & 0x00FF);
    this->payload[3] = (unsigned char) ((period_usec >> 24) & 0x00FF);
}
